local DD = AceLibrary("Dewdrop-2.0")
local L = AceLibrary("AceLocale-2.2"):new("MobileVault")
local self = MobileVault

local opts = {
		type='group',
		args = {
			show = {
				type = 'execute',
				name = L["Toggle Frame"],
				desc = L["Show or Hide the Guild Vault Image Frame"],
				func = "ToggleFrame",
				order = 6,
			},
			gather = {
				type = 'toggle',
				name = L["Gather Data"],
				desc = L["Toggle whether or not MGV will take an image of your guild bank."],
				get = function() return self.db.profile.gather end,
				set = function() self.db.profile.gather = not self.db.profile.gather end,
				order = 2,
			},
			delete = {
				type = 'text',
				name = L["Delete"],
				desc = L["Delete the specified guild's data table"],
				usage = L["<name of guild>"],
				get = false,
				set = function(text)
					if self.db.realm.guilds[text] then
						if text == self.GuildName then
							self:Unpopulate()
						end
						self.db.realm.guilds[text] = nil
						self:Print(text.." "..L["has been cleared from the Database."])
					else
						self:Print(text.." "..L["does not have any data stored with MGV."])
					end
				end,
				order = 4,
			},
			printDB = {
				type = 'execute',
				name = L["Print DB Names"],
				desc = L["Print out a list of all populated guild databases."],
				func = function()
					for k, v in pairs(self.db.realm.guilds) do
						self:Print(k)
					end
				end,
				order = 3,
			},
			scan = {
				type = 'execute',
				name = L["Scan"],
				desc = L["Runs a scan of the Guild Bank if it is already open."],
				func = "RefreshScan",
				order = 1,
			},
			visuals = {
				type = 'group',
				name = L["Visuals"],
				desc = L["Options for the visual aspects of the addon."],
				order = 5,
				args = {
					textcolor = {
						type = 'color',
						name = L["Text Color"],
						desc = L["Set the text color."],
						get = function() return self.db.profile.Tred, self.db.profile.Tgreen, self.db.profile.Tblue end,
						set = function(r, g, b)
							self.db.profile.Tred, self.db.profile.Tgreen, self.db.profile.Tblue = r, g, b
							self.anchor.text:SetTextColor(r, g, b, 1)
							if self.SplashScreen then
								self.SplashScreen.text:SetTextColor(r, g, b, 1)
							end
							self.Bottom.scan:SetTextColor(r, g, b, 1)
							self.Bottom.gold:SetTextColor(r, g, b, 1)
						end,
					},
					color = {
						type = 'color',
						name = L["Frame Color"],
						desc = L["Set the color of the image frame"],
						get = function() return self.db.profile.red, self.db.profile.green, self.db.profile.blue end,
						set = function(r, g, b)
							self.db.profile.red, self.db.profile.green, self.db.profile.blue = r, g, b
							self.anchor:SetBackdropColor(r, g, b, .7)
							for page = 1, 6 do
								for subframe = 1, 7 do
									for slot = 1, 14 do
										self.pages[page].subframes[subframe].slots[slot]:SetBackdropColor(r, g, b, 1)
									end
									self.pages[page].subframes[subframe]:SetBackdropColor(r, g, b, .65)
								end
								self.pages[page]:SetBackdropColor(r, g, b, 1)
							end
							for tab = 1, 6 do
								self.tab_buttons[tab]:SetBackdropColor(r, g, b, 1)
							end
						end,
					},
					border = {
						type = 'color',
						name = L["Border Color"],
						desc = L["Set the Slot Border Color"],
						get = function() return self.db.profile.Bred, self.db.profile.Bgreen, self.db.profile.Bblue end,
						set = function(r, g, b)
							self.db.profile.Bred, self.db.profile.Bgreen, self.db.profile.Bblue = r, g, b
							for page = 1, 6 do
								for subframe = 1, 7 do
									for slot = 1, 14 do
										self.pages[page].subframes[subframe].slots[slot]:SetBackdropBorderColor(r, g, b, 1)
									end
								end
							end
						end,
					},
					clicked = {
						type = 'color',
						name = L["Clicked Color"],
						desc = L["Sets the color for the active tab button"],
						get = function() return self.db.profile.Cred, self.db.profile.Cgreen, self.db.profile.Cblue end,
						set = function (r, g, b) self.db.profile.Cred, self.db.profile.Cgreen, self.db.profile.Cblue = r, g, b end,
					},
					highlight = {
						type = 'color',
						name = L["Highlight Color"],
						desc = L["Set the Slot Hightlight Color"],
						get = function() return self.db.profile.Hred, self.db.profile.Hgreen, self.db.profile.Hblue end,
						set = function(r, g, b) self.db.profile.Hred, self.db.profile.Hgreen, self.db.profile.Hblue = r, g, b end,
					},
				},
			},
		},
	}
	
opts.args.config = {
	type = "execute",
	name = L["Configuration"],
	desc = L["Show the GUI configuration menu."],
	guiHidden = true,
	func = function() DD:Open(UIParent, 'children', function() DD:FeedAceOptionsTable(opts) end, 'cursorX', true, 'cursorY', true) end,
}

self.MenuRequest = opts
MobileVault:RegisterChatCommand(L["Slash-Commands"], opts)